local AddOnName = ...;
local AddOn = LibStub("AceAddon-3.0"):NewAddon(AddOnName, "AceEvent-3.0");
local DataObject = LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject(AddOnName)

local function UpdateDataObject()
    if IsInGroup() then
        DataObject.text = ITEM_QUALITY_COLORS[GetLootThreshold()].hex .. UnitLootMethod[GetLootMethod()].text .. FONT_COLOR_CODE_CLOSE
    else
        DataObject.text = SOLO
    end
end

function DataObject:OnClick()
    if IsInGroup() then
        RandomRoll("1", "100")
    end
end

function DataObject:OnTooltipShow()
    if IsInGroup() then
        local lootMethod, lootMaster = GetLootMethod()
        local tooltipText
        if lootMethod == "personalloot" then
            tooltipText = OPT_OUT_LOOT_TOGGLE_OFF
        else
            tooltipText = UnitLootMethod[lootMethod].tooltipText
        end
        self:AddLine(UnitLootMethod[lootMethod].text, HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b)
        self:AddLine(tooltipText, NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b, true)
        if lootMethod ~= "personalloot" then
            local lootThreshold = GetLootThreshold()
            local r, g, b = GetTableColor(ITEM_QUALITY_COLORS[lootThreshold])
            self:AddLine(" ")
            self:AddDoubleLine(LOOT_THRESHOLD, _G["ITEM_QUALITY"..lootThreshold.."_DESC"], NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b, r, g, b)
            if lootMaster ~= nil then
                local unit = lootMaster == 0 and "player" or "party"..lootMaster
                local localizedClass, englishClass = UnitClass(unit)
                r, g, b = GetTableColor(RAID_CLASS_COLORS[englishClass])
                self:AddDoubleLine(MASTER_LOOTER, UnitName(unit), NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b, r, g, b)
            end
        end
    end
end

function DataObject:OnEnter()
	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint("TOPLEFT", self, "BOTTOMLEFT")
	GameTooltip:ClearLines()
	DataObject.OnTooltipShow(GameTooltip)
	GameTooltip:Show()
end

function DataObject:OnLeave()
	GameTooltip:Hide()
end

function AddOn:OnInitialize()
    DataObject.type = "data source"
    DataObject.icon = "Interface\\LootFrame\\LootPanel-Icon"
    
    self:RegisterEvent("PARTY_LOOT_METHOD_CHANGED", UpdateDataObject)
    self:RegisterEvent("PARTY_LEADER_CHANGED", UpdateDataObject)
    self:RegisterEvent("GROUP_ROSTER_UPDATE", UpdateDataObject)
    
    UpdateDataObject()
end
